@@ -8,39 +8,9 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com timehome@corp.globo.com
 
-import traceback
 import sys
 import argparse
 import logging
-import time
-
-import zmq
-
-from remotecv.app import RemoteCvApp
-from remotecv.utils import logger
-
-def run_server(host, port):
-    app = RemoteCvApp()
-    context = zmq.Context()
-    rep = context.socket(zmq.REP)
-    bind_address = 'tcp://%s:%s' % (host, port)
-
-    logger.debug('listening connections at %s' % bind_address)
-
-    rep.bind(bind_address)
-    while True:
-        result = ''
-        msg = rep.recv()
-        try:
-            start_time = time.time()
-            logger.debug('Accepting message')
-            result = app.process_request(msg)
-        except:
-            logger.error(traceback.format_exc())
-
-        rep.send(result)
-        logger.debug('Sending response. Ellapsed: %d' % ((time.time() - start_time) * 1000))
-
 
 def main(params=None):
     if params is None:
@@ -50,15 +20,16 @@ def main(params=None):
     conn_group = parser.add_argument_group('Connection arguments')
     conn_group.add_argument('-b', '--bind', default='*', help='IP address to bind')
     conn_group.add_argument('-p', '--port', default=13337, type=int, help='Port to listen')
+    conn_group.add_argument('-s', '--server-type', default='zmq', choices=['zmq', 'tornado'], help="Server type")
 
     other_group = parser.add_argument_group('Other arguments')
     other_group.add_argument('-l', '--level', default='debug', help='Logging level')
 
     arguments = parser.parse_args(params)
-
     logging.basicConfig(level=getattr(logging, arguments.level.upper()))
 
-    run_server(arguments.bind, arguments.port)
+    server_module = __import__("%s_server" % arguments.server_type)
+    server_module.run_server(arguments.bind, arguments.port)
 
 
 if __name__ == "__main__":
